@@ -1,9 +1,7 @@
 package Dancer::Session::CHI;
 
-use v5.10;
-use strict;
-use warnings;
-use utf8::all;
+use strictures 1;
+use utf8;
 use namespace::autoclean 0.13;
 use CHI 0.49;
 use Dancer 1.3072 qw/config debug/;
@@ -11,13 +9,11 @@ use English '-no_match_vars';
 use Moose 2.0205;
 use MooseX::ClassAttribute 0.26;
 use MooseX::NonMoose 0.22;
-use MooseX::InsideOut 0.106;
-use MooseX::Types::Moose 0.30 'HashRef';
 use Scalar::Util 'blessed';
 
 extends 'Dancer::Session::Abstract';
 
-our $VERSION = 'v0.0.3'; # VERSION
+our $VERSION = 'v0.0.4'; # VERSION
 # ABSTRACT: CHI-based session engine for Dancer
 
 class_has _cache => (
